package lambdas2;

class ColorUtil{
	private ColorUtil(){}

	/**
	 * Zamienia liczbę HEX na RGB
	 * @param hexa String - liczba typu 0xFFFFFF podawana jest jako
	 * "FFFFFF" bez 0x
	 * @return String - wartość RGB
	 */
	public static String HexToRGB(String hexa) {
		Integer R = Integer.valueOf(hexa.substring(0, 2), 16);
		Integer G = Integer.valueOf(hexa.substring(2, 4), 16);
		Integer B = Integer.valueOf(hexa.substring(4, 6), 16);
		return ("RGB:[" + R + "," + G + "," + B + "]");
	}

	/**
	 * Zamienia liczbę HEX na RGB
	 * @param hexa int - podajemy liczbę typu 0xFFFFFF
	 * @return String - wartość RGB
	 */
	public static String HexToRGB(int hexa) {
		int R = (hexa >> 16) & 0xff;
		int G = (hexa >> 8) & 0xff;
		int B = hexa & 0xff;
		return ("RGB:[" + R + "," + G + "," + B + "]");
	}

	/**
	 * Zamienia wartosci R, G, B na liczbę HEX
	 * @param r int - składnik czerwony
	 * @param g int - składnik zielony
	 * @param b int - składnik niebieski
	 * @return String - waartość HEX
	 */
	public static String RGBToHex(int r, int g, int b) {
		String r1 = Integer.toString(r, 16);
		String g1 = Integer.toString(g, 16);
		String b1 = Integer.toString(b, 16);
		if(r1.length() == 1){
			r1 = "0" + r1;
		}
		if(g1.length() == 1){
			g1 = "0" + g1;
		}
		if(b1.length() == 1){
			b1 = "0" + b1;
		}
		return "0x" + r1 + g1 + b1;
	}

	/**
	 *Zamienia wartosci R, G, B na liczbę int stosowaną w Javie
	 *@param r int - składnik czerwony;
	 *@param g int - składnik zielony
	 *@param b int - składnik niebieski
	 *@return int - wartość RGB przeliczona na int; 
	 */
	public static int RGBToInt(int r, int g, int b) {
		String r1 = Integer.toString(r, 16);
		String g1 = Integer.toString(g, 16);
		String b1 = Integer.toString(b, 16);
		if(r1.length() == 1){
			r1 = "0" + r1;
		}
		if(g1.length() == 1){
			g1 = "0" + g1;
		}
		if(b1.length() == 1){
			b1 = "0" + b1;
		}
		String cont = "" + r1 + g1 + b1;
		int i = Integer.valueOf(cont, 16);
		int col = (i | 0x00 << 16 | 0x00 << 8 | 0x00);
		return col;
	}

	/**
	 * Przelicza liczbę int na R, G, B
	 * @param rgb int - liczba int oznaczająca kolor;
	 * @return String - wartość RGB
	 */
	public static String IntToRGB(int rgb) {
		int R = (rgb >> 16) & 0xff;
		int G = (rgb >> 8) & 0xff;
		int B = (rgb >> 0) & 0xff;
		return ("RGB:[" + R + "," + G + "," + B + "]");
	}

	/**
	 *Zamienia wartosci R, G, B, A na liczbę int stosowaną w Javie
	 *@param r int - składnik czerwony;
	 *@param g int - składnik zielony
	 *@param b int - składnik niebieski
	 *@param a int - składnik alfa
	 *@return int - wartość RGB przeliczona na int; 
	 */
	public static int RGBAToInt(int r, int g, int b, int a) {
		String a1 = Integer.toString(a, 16);
		String r1 = Integer.toString(r, 16);
		String g1 = Integer.toString(g, 16);
		String b1 = Integer.toString(b, 16);
		if(a1.length() == 1){
			a1 = "0" + a1;
		}
		if(r1.length() == 1){
			r1 = "0" + r1;
		}
		if(g1.length() == 1){
			g1 = "0" + g1;
		}
		if(b1.length() == 1){
			b1 = "0" + b1;
		}
		String cont = "" + a1 + r1 + g1 + b1;
		int i = Integer.valueOf(cont, 16);
		int col = (i | 0x00 << 24 | 0x00 << 16 | 0x00 << 8 | 0x00);
		return col;
	}

	/**
	 * Przelicza liczbę int na R, G, B, A
	 * @param rgba int - liczba int oznaczająca kolor;
	 * @return String - wartość RGBA
	 */
	public static String IntToRGBA(int rgba) {
		int A = (rgba >> 24) & 0xff;
		int R = (rgba >> 16) & 0xff;
		int G = (rgba >> 8) & 0xff;
		int B = (rgba >> 0) & 0xff;
		return ("RGBA:[" + R + "," + G + "," + B + "," + A + "]");
	}
}
